# -*- coding: utf-8 -*-
##
## Copyright (C)2005 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""PloneExFile tests

$Id: PloneExFileTestCase.py 6246 2007-08-06 11:57:21Z glenfant $
"""
__docformat__ = 'restructuredtext'

__author__ = ''

# Python imports
import os

# Zope imports
from Testing import ZopeTestCase
from AccessControl.SecurityManagement import newSecurityManager
from AccessControl.SecurityManagement import noSecurityManager
from OFS.Image import File
import transaction

# CMF imports
try:
    from Products.CMFCore import permissions as CMFCorePermissions
except ImportError:
    from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils import getToolByName

# Plone imports
from Products.PloneTestCase import PloneTestCase

# Products imports
from Products.PloneExFile.Permissions import EditExFile

portal_name = PloneTestCase.portal_name
portal_owner = PloneTestCase.portal_owner
portal_member = 'portal_member'

def _getMemberareaCreationFlag():
    """
    Monkey patchfor membership tool
    """
    return True

class PloneExFileTestCase(PloneTestCase.PloneTestCase):
    """ PloneExFile test case based on a plone site"""

    def afterSetUp(self):
        # Tools shortcuts
        self.cat_tool = getToolByName(self.portal, 'portal_catalog')
        self.type_tool = getToolByName(self.portal, 'portal_types')
        self.wf_tool = getToolByName(self.portal, 'portal_workflow')
        self.mb_tool = getToolByName(self.portal, 'portal_membership')
        self.mb_tool.getMemberareaCreationFlag = _getMemberareaCreationFlag
        self.mb_tool.addMember(portal_member, 'azerty', ['Member'], ())
        self.mb_tool.createMemberArea(portal_member)
        self.member_folder = self.mb_tool.getHomeFolder(portal_member)
        return

    def createEmptyFile(self, container, content_id = 'file', **kwargs):
        # return empty file
        container.invokeFactory(type_name='PloneExFile', id=content_id, **kwargs)
        exfile = getattr(container, content_id)
        return exfile

    def _testDocPath(self):
        # Full path to a test doc file
        fpath = os.path.join(os.path.dirname(__file__), 'test.doc')
        return fpath

    def createFullFile(self, container, content_id = 'file'):
        # create full file
        upload_file = self.createFileObject('test.doc', self._testDocPath())
        return self.createEmptyFile(container, content_id, file=upload_file)


    def createFileObject(self, file_id, file_path):
        f = file(file_path, 'rb')
        file_obj = File(file_id, file_id, f)
        setattr(file_obj, 'filename', file_id)
        f.close()

        return file_obj

    def beforeTearDown(self):
        # logout
        noSecurityManager()

    def loginAsPortalMember(self):
        '''Use if you need to manipulate an exfile as member.'''
        uf = self.portal.acl_users
        user = uf.getUserById(portal_member).__of__(uf)
        newSecurityManager(None, user)

    def loginAsPortalMember2(self):
        '''Use if you need to manipulate an exfile as member.'''
        uf = self.portal.acl_users
        user = uf.getUserById(portal_member2).__of__(uf)
        newSecurityManager(None, user)

    def loginAsPortalMember3(self):
        '''Use if you need to manipulate an exfile as member.'''
        uf = self.portal.acl_users
        user = uf.getUserById(portal_member3).__of__(uf)
        newSecurityManager(None, user)

    def loginAsPortalOwner(self):
        '''Use if you need to manipulate an exfile as member.'''
        uf = self.app.acl_users
        user = uf.getUserById(portal_owner).__of__(uf)
        newSecurityManager(None, user)


ZopeTestCase.installProduct('AttachmentField')
ZopeTestCase.installProduct('PloneExFile')
PloneTestCase.setupPloneSite(products=['kupu', 'AttachmentField', 'PloneExFile'])

app = ZopeTestCase.app()
ZopeTestCase.close(app)
