# -*- coding: utf-8 -*-
## 
## Copyright (C) 2005-2007 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
PloneExFile main test case
$Id: testPloneExFile.py 6242 2007-08-06 11:31:10Z glenfant $
"""

__docformat__ = 'restructuredtext'
__author__ = ''

import unittest

from Acquisition import aq_base

from common import *

tests = []

class TestPloneExFile(PloneExFileTestCase):

    def testAddPloneExFile(self):
        """ test if PloneExFile is created """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createEmptyFile(self.member_folder, content_id)
        self.failUnless(hasattr(aq_base(self.member_folder), content_id))

    def testIsIndexed(self):
        """ test if PloneExFile is indexed """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createEmptyFile(self.member_folder, content_id)
        self.failUnless(self.cat_tool(id=content_id))

    def testReindexPloneExFile(self):
        """ Modify the title and re index PloneExFile """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createEmptyFile(self.member_folder, content_id)
        self.failIf(self.cat_tool(id=content_id, Title='My File'))
        exfile.setTitle('My File')
        exfile.reindexObject()
        self.failUnless(self.cat_tool(id=content_id, Title='My File'))

    #Standard Plone tools

    def testDeletePloneExFile(self):
        """ delete PloneExFile """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createEmptyFile(self.member_folder, content_id)
        self.member_folder._delObject(content_id)
        self.failIf(self.cat_tool(id=content_id))
        return



    ###############################
    #PloneExFile related method#
    ###############################

    def testEditPloneExFile(self):
        """ edit the PloneExFile """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createEmptyFile(self.member_folder, content_id)
        title = 'My File'
        description = 'Document speaking of general economy'
        exfile.setTitle(title)
        exfile.setDescription(description)

        #edit our product with title and description
        self.assertEqual(exfile.Title(), title)
        self.assertEqual(exfile.Description(), description)
        return

    def testAddFile(self):
        """
        Add a file,
        verify hasAttachment(),
        verify if file is correctly uploaded.
        """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createFullFile(self.member_folder, content_id)
        file_field = exfile.getField('file')
        file_field_content = file_field.get(exfile).get_data()

        self.failUnless(file_field.isIndexed(exfile))
        self.failUnless(len(file_field.getIndexableValue(exfile)) > 500)
        f = file(self._testDocPath(), 'rb')
        file_content = f.read()
        f.close()

        self.assertEquals(len(file_field_content), len(file_content))
        self.failUnless(
            file_field_content == file_content,
            "File content is different.",
            )

    def testMassiveAddFile(self):
        """
        Add many files,
        """
        self.loginAsPortalMember()

        for x in range(0, 1):
            content_id = "exfile%03d" % x
            exfile = self.createFullFile(self.member_folder, content_id)
            file_field = exfile.getField('file')
            file_field_content = file_field.get(exfile).get_data()

            
            f = file(self._testDocPath(), 'rb')
            file_content = f.read()
            f.close()
            self.failUnless(
                file_field_content == file_content,
                "File content is different.",
                )


    def testDeleteFile(self):
        """ Add a file and delete it """
        self.loginAsPortalMember()
        content_id = 'my_file'
        exfile = self.createFullFile(self.member_folder, content_id)
        file_field = exfile.getField('file')

        self.assertEqual(file_field.isEmpty(exfile), 0)

        file_field.set(exfile, 'DELETE_FILE')
        self.assertEqual(file_field.isEmpty(exfile), 1)


tests.append(TestPloneExFile)

def test_suite():
    suite = unittest.TestSuite()
    for test in tests:
        suite.addTest(unittest.makeSuite(test))
    return suite
